@@ -13,6 +13,7 @@ import tarfile
 import tempfile
 from io import BytesIO
 
+from splunk_appinspect.checks import Check
 from splunk_appinspect.configuration_parser import InvalidSectionError
 from splunk_appinspect.python_modules_metadata import python_modules_metadata_store
 
@@ -29,6 +30,7 @@ from . import (
     custom_visualizations,
     distsearch_configuration_file,
     file_resource,
+    file_view,
     indexes_configuration_file,
     inputs_configuration_file,
     inputs_specification_file,
@@ -107,6 +109,14 @@ class App(object):
         self._static_slim_app_dependencies = None
         self.python_analyzer_enable = python_analyzer_enable
 
+        # Setup file view
+        self.app_file_view = self.get_file_view()
+
+        # Setup merged configuration holders
+        self._default_config = None
+        self._local_config = None
+        self._merged_config = None
+
         # initialize trusted libs manager
         self._trusted_libs_manager = trusted_libs_manager
         self.LINUX_ARCH = "linux"
@@ -306,7 +316,9 @@ class App(object):
             # Makes generic configuration file if no specified configuration file is
             # passed in
             if config_file is None:
-                config_file = configuration_file.ConfigurationFile()
+                config_file = configuration_file.ConfigurationFile(
+                    relative_path=os.path.relpath(app_filepath, self.app_dir)
+                )
 
             with open(app_filepath, "rb") as file:
                 try:
@@ -667,10 +679,19 @@ class App(object):
                             check_name, current_frame = None, inspect.currentframe()
                             while current_frame:
                                 name = current_frame.f_code.co_name
-                                if name.startswith("check_"):
-                                    check_name = name
-                                    break
+                                f_locals = current_frame.f_locals
+                                varnames = current_frame.f_code.co_varnames
+                                if (
+                                    name == "run"
+                                    and "self" in varnames
+                                    and issubclass(type(f_locals["self"]), Check)
+                                ):
+                                    # This is Check.run, where `self` is the Check object
+                                    # so we can get `self` from f_locals
+                                    check_name = f_locals["self"].name
+
                                 current_frame = current_frame.f_back
+
                             if not self._filter_by_trusted_libs(
                                 dir_in_app, file, check_name
                             ):
@@ -1150,3 +1171,77 @@ class App(object):
         except Exception:
             logger.error("read file %s failed", filepath)
         return False
+
+    def get_file_view(self, *paths):
+        """Returns a FileView mounted on a given subdirectory of the app directory
+
+        Args:
+            *paths: a list of path segments which are joined to form the FileView path
+
+        Returns:
+            FileView: a FileView looking at the given path"""
+        return file_view.FileView(self, os.path.join(*paths) if paths else "")
+
+    @property
+    def lookups(self):
+        """FileView: Returns a FileView for the `lookups` directory"""
+        return self.get_file_view("lookups")
+
+    @property
+    def default_config(self):
+        """ConfigurationProxy: lazily initializes a configuration proxy looking at the
+        `default` directory"""
+        if self._default_config is None:
+            self._default_config = configuration_file.ConfigurationProxy(
+                self, "default"
+            )
+
+        return self._default_config
+
+    @property
+    def default_file_view(self):
+        """FileView: Returns a FileView for the `default` directory, or None if
+        the directory does not exist"""
+        if "default" in self.app_file_view:
+            return self.app_file_view["default"]
+        return None
+
+    @property
+    def local_config(self):
+        """ConfigurationProxy: lazily initializes a configuration proxy looking at the
+        `local` directory"""
+        if self._local_config is None:
+            self._local_config = configuration_file.ConfigurationProxy(self, "local")
+
+        return self._local_config
+
+    @property
+    def local_file_view(self):
+        """FileView: Returns a FileView for the `local` directory, or None if
+        the directory does not exist"""
+        if "local" in self.app_file_view:
+            return self.app_file_view["local"]
+        return None
+
+    @property
+    def merged_config(self):
+        """ConfigurationProxy: lazily initializes a merged configuration proxy looking first
+        at the `local` directory, then the `default` directory"""
+        if self._merged_config is None:
+            return configuration_file.MergedConfigurationProxy(
+                self.local_config, self.default_config
+            )
+
+        return self._merged_config
+
+    @property
+    def merged_file_view(self):
+        """MergedFileView: Returns a MergedFileView which returns files first
+        from the `local` FileView, if `local` exists, then from the `default`
+        FileView, if `default` exists."""
+        views = []
+        if self.local_file_view:
+            views.append(self.local_file_view)
+        if self.default_file_view:
+            views.append(self.default_file_view)
+        return file_view.MergedFileView(*views)
