@@ -8,6 +8,7 @@ The **app.conf** file located at **default/app.conf** provides key application i
 
 import logging
 import os
+from pathlib import Path
 import re
 
 import splunk_appinspect
@@ -499,3 +500,49 @@ def _is_package_id_valid(package_id):
         return False
 
     return True
+
+
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
+def check_custom_conf_replication(app, reporter):
+    """
+    Check that custom .conf files have a a matching conf_replication_include.<conf_file_name> value in server.conf,
+    under the [shclustering] stanza, to ensure that configurations are synchronized across Search Head Clusters.
+    """
+    custom_configs = []
+    for directory, filename, _ in app.iterate_files(types=[".conf"], basedir=["default", "local"]):
+        if filename not in SPLUNK_DEFINED_CONFS:
+            custom_configs.append(os.path.join(directory, filename))
+
+    server_configs = []
+    for directory in ["default", "local"]:
+        if app.file_exists(directory, "server.conf"):
+            server_conf = app.server_conf()
+            server_conf.name = os.path.join(directory, "server.conf")
+            server_configs.append(server_conf)
+
+    for custom_config in custom_configs:
+        custom_config_name = Path(custom_config).stem
+        is_found = False
+        for server_config in server_configs:
+            shclustering_section = server_config.get_section("shclustering")
+            for name, value, lineno in shclustering_section.items():
+                if name == f"conf_replication_include.{custom_config_name}":
+                    is_found = True
+                    break
+        if not is_found:
+            reporter.warn(
+                f"{custom_config} exists but conf_replication_include.{custom_config_name} "
+                f"setting is not set in server.conf"
+            )
+
+    for server_config in server_configs:
+        if server_config.has_section("shclustering"):
+            shclustering_section = server_config.get_section("shclustering")
+            for name, value, lineno in shclustering_section.items():
+                if name.startswith("conf_replication_include."):
+                    custom_conf = f"{name[len('conf_replication_include.'):]}"
+                    if custom_conf not in [Path(c).stem for c in custom_configs]:
+                        reporter.warn(
+                            f"{name} setting in sever.conf "
+                            f"but does not match custom config file. File: {server_config.name}. Line: {lineno}."
+                        )
\ No newline at end of file
