@@ -205,32 +205,3 @@ def check_that_app_name_config_is_valid(app, reporter):
         reporter.fail(reporter_output)
     else:
         pass
-
-
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
-@splunk_appinspect.cert_version(min="1.7.0")
-def check_splunklib_dependency_under_bin_folder(app, reporter):
-    """Check splunklib dependency should not be placed under app's `bin` folder. Please refer to
-    https://dev.splunk.com/view/SP-CAAAER3 and https://dev.splunk.com/view/SP-CAAAEU2 for more details/examples."""
-    results_py_file_hashes = {
-        "51dacaa440c6dbeff900121662eaa849",
-        "6c93de35d5b57704f304214677cd926e",
-        "782d580beee042aeab31cc3fdc27ee62",
-        "27d37b88995d12262e1cb87a4e0517b7",
-        "118762ec2ee09df3e797f4f3c0b4d2cb",
-        "2637064e1456fa163da294092e60de96",
-        "094c9718010b4703e399843ecd48cbfe",
-        "ac583c645b99368f9ba51ab2e6d01597",
-        "f75aa820dfa1e8227039f5fc059100d2",
-    }
-    for directory, file, _ in app.iterate_files(basedir="bin", types=[".py"]):
-        if file == "results.py":
-            filename = os.path.join(app.app_dir, directory, file)
-            md5_hash = md5(filename)
-            if md5_hash in results_py_file_hashes:
-                reporter.warn(
-                    "splunklib is found under `bin` folder, this may cause some dependency management "
-                    "errors with other apps, and it is not recommended. Please follow examples in Splunk "
-                    "documentation to include splunklib. You can find more details here: "
-                    "https://dev.splunk.com/view/SP-CAAAEU2 and https://dev.splunk.com/view/SP-CAAAER3"
-                )
