@@ -13,7 +13,7 @@ logger = logging.getLogger(__name__)
 report_display_order = 5
 
 
-@splunk_appinspect.tags("splunk_appinspect", "bias", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "bias", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.3.0")
 def check_for_bias_language(app, reporter):
     """Check that the app does not include any bias words."""
