@@ -13,7 +13,7 @@ logger = logging.getLogger(__name__)
 report_display_order = 13
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.0")
 def check_validate_json_data_is_well_formed(app, reporter):
     """Check that all JSON files are well formed."""
