@@ -8,8 +8,10 @@ import logging
 import os
 import platform
 import re
+import semver
 
 import splunk_appinspect
+from splunk_appinspect.regex_matcher import RegexBundle, RegexMatcher
 from splunk_appinspect.check_routine.python_ast_searcher.ast_searcher import AstSearcher
 from splunk_appinspect.check_routine.python_ast_searcher.node_filters import (
     is_sub_class_def,
@@ -899,3 +901,50 @@ def check_for_debugging_and_profiling(app, reporter):
     message = "The following lines should be inspected during code review, `{}` could be used to execute arbitrary commands."
     files_with_results = AstSearcher(app.python_analyzer_client).search(check_objects)
     reporter.ast_manual_check(message, files_with_results)
+
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "security")
+def check_python_httplib2_version(app, reporter):
+    """Check python httplib2 version."""
+    min_ver = semver.VersionInfo.parse("0.19.1")
+    ver_rex = '__version__ = "([\d.]+)"'
+    httplib2_exists = False
+    py_files = list(app.iterate_files(types=[".py"]))
+    # Look for __version__ = "0.18" in httplib2/__init__.py
+    rexs = [RegexBundle(ver_rex)]
+    matcher = RegexMatcher(rexs)
+    if py_files:
+        for directory, file, _ in py_files:
+            if not (file == "__init__.py" and directory.endswith("httplib2" + os.sep)):
+                continue
+            file_path = os.path.join(directory, file)
+            full_file_path = app.get_filename(file_path)
+            match_result = matcher.match_file(filepath=full_file_path)
+            for lineno, result in match_result:
+                httplib2_exists = True
+                file_path = os.path.join(directory, file)
+                # Parse the found version into semver, correcting for
+                # bad versions like "0.1" without a patch version
+                try:
+                    ver = re.search(ver_rex, result).groups()[0]
+                    if len(ver.split(".")) == 2:
+                        ver += ".0"  # correct for versions without a patch
+                    parsed_ver = semver.VersionInfo.parse(ver)
+                except Exception as err:
+                    reporter_output = ("Issue parsing version found in for the python httplib2"
+                                       f" ({ver}). File: {file_path}. Error: {err}.")
+                    reporter.warn(reporter_output, file_path)
+                    continue
+
+                if parsed_ver < min_ver:
+                    # Found httplib2 version is less than the minimum
+                    reporter_output = ("Detected an outdated version of the Python httplib2"
+                                       f" ({ver}). Please upgrade to version "
+                                       f"{min_ver[0]}.{min_ver[1]}.{min_ver[2]} or later. "
+                                       f"File: {file_path}.")
+                    reporter.warn(reporter_output, file_path)
+
+    # httplib2/__init__.py not found
+    if not httplib2_exists:
+        reporter_output = "Python httplib2 library not found."
+        reporter.not_applicable(reporter_output)
+
