@@ -29,21 +29,6 @@ def tags(*args):
     return wrap
 
 
-def deferred(*args):
-    """
-    Designates that the decorated check should be deferred and run at the end of the run
-    """
-    # Though bumped to the end, there is still no order- merely tiers. Order can be
-    # trivially supported, but I'm reluctant to allow easy ordering of tests- in my
-    # opinion, relying on test order makes for more fragile tests and a less maintainable
-    # test suite.
-    def wrap(check):
-        check.deferred = True
-        return check
-
-    return wrap
-
-
 def display(report_display_order=1000):
     """
     Allows specifying an order for checks to appear within a group
