@@ -4,6 +4,7 @@ import logging
 import os
 import re
 
+from .configuration_file import ConfigurationSetting
 from . import inspected_file
 
 logger = logging.getLogger(__name__)
@@ -21,6 +22,9 @@ class RegexMatcher(object):
 
     def match(self, string, regex_option=0):
         """return all match results in sorted order"""
+        if isinstance(string, ConfigurationSetting):
+            string = string.value
+
         ans = []
         for regex_bundle in self.__regex_bundle_list:
             pattern = re.compile(regex_bundle.general_regex_string, regex_option)
