@@ -193,6 +193,25 @@ class Reporter(object):
 
         return tailored_message
 
+    def report(self, message):
+        """Called by CheckMessage.report"""
+        if message.result in ("success",):
+            # Do not report success results
+            return
+
+        reporter_output = self.__format_message(
+            message.message,
+            message_file_name=message.file_name,
+            message_line_number=message.line_number
+        )
+        self.__save_result_message(
+            message.result,
+            reporter_output,
+            message.frame,
+            message_file_name=message.file_name,
+            message_line_number=message.line_number,
+        )
+
     def warn(self, message, file_name=None, line_number=None):
         """A warn will require that the app be inspected by a real human. Like a
         todo item
@@ -208,11 +227,6 @@ class Reporter(object):
             message_line_number=line_number,
         )
 
-    def assert_warn(self, assertion, message, file_name=None, line_number=None):
-        """If assertion is false, log a warning"""
-        if not assertion:
-            self.warn(message, file_name, line_number)
-
     def manual_check(self, message, file_name=None, line_number=None):
         """Declare that this check requires a human to validate"""
         reporter_output = self.__format_message(
@@ -226,11 +240,6 @@ class Reporter(object):
             message_line_number=line_number,
         )
 
-    def assert_manual_check(self, assertion, message, file_name=None, line_number=None):
-        """If assertion is false, add to a human's todo list"""
-        if not assertion:
-            self.manual_check(message, file_name, line_number)
-
     def not_applicable(self, message):
         """Report that this check does not apply to the current app"""
         self.__save_result_message("not_applicable", message, inspect.currentframe())
@@ -241,11 +250,6 @@ class Reporter(object):
         self.__save_result_message("skipped", message, inspect.currentframe())
         logger.debug(message)
 
-    def assert_not_applicable(self, assertion, message):
-        """If assertion is false, put this in a human's queue"""
-        if not assertion:
-            self.not_applicable(message)
-
     def fail(self, message, file_name=None, line_number=None):
         """Failure is when a problem has been found that the app can't be
         accepted without fixing
@@ -286,11 +290,6 @@ class Reporter(object):
                         line_number=result["line_number"],
                     )
 
-    def assert_fail(self, assertion, message, file_name=None, line_number=None):
-        """If assertion is false, log failure"""
-        if not assertion:
-            self.fail(message, file_name, line_number)
-
     def exception(self, exception, category="error"):
         """Error is when there's something wrong with the check script.
         Don't call this directly- just throw an exception
